/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.repository.actions');

//------------------ ADD NODE -----------------------//
org.ametys.repository.actions.AddNode = function (parentNode, workspaceName, callback)
{
	org.ametys.repository.actions.AddNode._parentNode = parentNode;
	org.ametys.repository.actions.AddNode._workspaceName = workspaceName;
	org.ametys.repository.actions.AddNode._callback = callback;
	
	org.ametys.repository.actions.AddNode.act ();
}

org.ametys.repository.actions.AddNode.act = function ()
{
	if (!org.ametys.repository.actions.AddNode.delayedInitialize())
        return;
	
	org.ametys.repository.actions.AddNode.box.show();
	org.ametys.repository.actions.AddNode._initForm();
	
	org.ametys.repository.actions.AddNode._form.findField('name').focus(true, 200);
}

org.ametys.repository.actions.AddNode.delayedInitialize = function ()
{
	if (org.ametys.repository.actions.AddNode._initialized)
		return true;
	
	var formPanel = new Ext.FormPanel( {
		labelWidth: 100,
		bodyStyle: 'padding:10px',
		
		defaultType :'textfield',
		
		border: false,
		autoScroll: true,
		items: [
		        	new org.ametys.HtmlContainer ({cls: 'dialog-text-hint', html: "<i18n:text i18n:key="ADD_NODE_BOX_HINT"/>" }),
					new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="ADD_NODE_BOX_NAME_LABEL"/>",
						name: 'name',
					 	width: 200,
						allowBlank: false,
						msgTarget: 'side'
					}),
					new org.ametys.form.ComboField ({
						 fieldLabel: "<i18n:text i18n:key="ADD_NODE_BOX_TYPE_LABEL"/>",
						 name: 'type',
						 editable: false,
						 triggerAction: 'all',
					     width : 200,
					     displayField:'type',
					     valueField:'type',
					     mode: 'local',
						 store: [],
					     emptyText: "<i18n:text i18n:key="ADD_NODE_BOX_TYPE_COMBO_EMPTY"/>",
					     allowBlank: false,
						 msgTarget: 'side'
					})
		        ]
	});
	
	org.ametys.repository.actions.AddNode._form = formPanel.getForm();
	
	org.ametys.repository.actions.AddNode.box = new org.ametys.DialogBox({
		title :"<i18n:text i18n:key="ADD_NODE_BOX_TITLE"/>",
		icon : context.workspaceContext + "/resources/img/add_node_16.png",
		
		layout :'fit',
		cls: 'text-dialog',
		width: 420,
		height: 180,
		
		items : [ formPanel ],
		
		closeAction: 'hide',
		buttons : [ {
			text :"<i18n:text i18n:key="DIALOG_BOX_OK"/>",
			handler : org.ametys.repository.actions.AddNode.ok
		}, {
			text :"<i18n:text i18n:key="DIALOG_BOX_CANCEL"/>",
			handler : org.ametys.repository.actions.AddNode.cancel
		} ]
	});
	
	
	org.ametys.repository.actions.AddNode._initialized = true;
	
	return true;
}

org.ametys.repository.actions.AddNode._initForm = function ()
{
	org.ametys.repository.actions.AddNode._form.findField('name').setValue('');
	org.ametys.repository.actions.AddNode._form.findField('type').setValue('');
	org.ametys.repository.actions.AddNode._form.findField('name').clearInvalid();
	
	org.ametys.repository.actions.AddNode._loadTypes ();
}

org.ametys.repository.actions.AddNode._loadTypes = function()
{
    var path = org.ametys.repository.actions.AddNode._parentNode.attributes.path.substring(1);
	var workspaceName = org.ametys.repository.actions.AddNode._workspaceName;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, 'repository/children-types',
			{
				workspace: workspaceName,
				parentPath: path
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
			null, 
			this, 
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_NODE_TYPES"/>", response, "org.ametys.repository.actions.AddNode"))
	{
		return;
	}
	
	var types = response.selectSingleNode("typesList").selectNodes("type");
	var myData = [];	
	for (var i=0; i &lt; types.length; i++)
	{
		var type = types[i][org.ametys.servercomm.ServerComm.xmlTextContent];
		myData.push(type);		
	}
	myData.sort();
	
	var store = org.ametys.repository.actions.AddNode._form.findField('type').getStore();
	store.loadData(myData);
}

org.ametys.repository.actions.AddNode.ok = function ()
{
	if (!org.ametys.repository.actions.AddNode._form.isValid())
	{
		return;
	}
	
    var parentPath = org.ametys.repository.actions.AddNode._parentNode.attributes.path.substring(1);
	
	//add node in the JCR repository
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, '/repository/add-node',
			{
				workspace: org.ametys.repository.actions.AddNode._workspaceName,
				parentPath: parentPath,
				childName: org.ametys.repository.actions.AddNode._form.findField('name').getValue(),
				childType: org.ametys.repository.actions.AddNode._form.findField('type').getValue()
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_MAJOR,  
			org.ametys.repository.actions.AddNode._okCb, 
			this, 
			[]);
	
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.repository.actions.AddNode._okCb = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_ADD_NODE"/>", response, "org.ametys.repository.actions.AddNode"))
	{
		return;
	}
	
	var path = response.selectSingleNode('ActionResult').selectSingleNode('pathWithGroups')[org.ametys.servercomm.ServerComm.xmlTextContent];
	
	org.ametys.repository.actions.AddNode.box.hide();
	
	org.ametys.repository.actions.AddNode._parentNode.reload();
	
	if (typeof org.ametys.repository.actions.AddNode._callback == 'function')
    {
	    org.ametys.repository.actions.AddNode._callback(path);
    }
}

org.ametys.repository.actions.AddNode.cancel = function ()
{
	org.ametys.repository.actions.AddNode.box.hide();
}

//------------------ REMOVE NODE -----------------------//
org.ametys.repository.actions.RemoveNode = function (node, workspaceName, callback)
{
	org.ametys.repository.actions.RemoveNode._node = node;
	org.ametys.repository.actions.RemoveNode._workspaceName = workspaceName;
	org.ametys.repository.actions.RemoveNode._cb = callback;
	
	Ext.MessageBox.confirm(	"<i18n:text i18n:key="REMOVE_NODE_BOX_TITLE"/>",
							"<i18n:text i18n:key="REMOVE_NODE_BOX_HINT"/> &lt;br/&gt;" + node.id,
							org.ametys.repository.actions.RemoveNode.act,
							this);

}

org.ametys.repository.actions.RemoveNode.act = function (btn)
{
	if (btn == 'yes')
	{
		var workspaceName = org.ametys.repository.actions.RemoveNode._workspaceName;
		var path = org.ametys.repository.actions.RemoveNode._node.attributes.path.substring(1);
		
		var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, '/repository/remove-node',
				{
					workspace: workspaceName,
					path: path
				}, 
				org.ametys.servercomm.ServerComm.PRIORITY_MAJOR,  
				org.ametys.repository.actions.RemoveNode._callback, 
				this, 
				[path]);
		org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	}
}

org.ametys.repository.actions.RemoveNode._callback = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_REMOVE_NODE"/>", response, "org.ametys.repository.actions.RemoveNode"))
	{
		return;
	}
	
	var parentJcrNodePath = response.selectSingleNode('ActionResult/parent-path')[org.ametys.servercomm.ServerComm.xmlTextContent];
	
	// Refresh the parent node
	var parentTreeNode = org.ametys.repository.actions.RemoveNode._node.parentNode;
	parentTreeNode.reload(function (){parentTreeNode.select()});
	
	if (org.ametys.repository.actions.RemoveNode._cb != null)
    {
	    org.ametys.repository.actions.RemoveNode._cb(org.ametys.repository.actions.RemoveNode._node.attributes.path, parentTreeNode.attributes.path, parentJcrNodePath);
    }
}

//------------------ CHECKIN-CHECKOUT -----------------------//
org.ametys.repository.actions.CheckoutNode = function (node, workspaceName, callback)
{
	org.ametys.repository.actions.CheckoutNode._node = node;
	org.ametys.repository.actions.CheckoutNode._workspaceName = workspaceName;
	org.ametys.repository.actions.CheckoutNode._callback = callback;
	
	org.ametys.repository.actions.CheckoutNode.act();
}

org.ametys.repository.actions.CheckoutNode.act = function ()
{
	var path = org.ametys.repository.actions.CheckoutNode._node.attributes.path.substring(1);
	var workspaceName = org.ametys.repository.actions.CheckoutNode._workspaceName;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, '/repository/checkout-node',
			{
				workspace: workspaceName,
				path: path
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_MAJOR,  
			org.ametys.repository.actions.CheckoutNode._callback, 
			this, 
			null);
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.repository.actions.CheckoutNode._callback = function ()
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_CHECKOUT_NODE"/>", response, "org.ametys.repository.actions.checkoutNode"))
	{
		return;
	}
	
	if (typeof org.ametys.repository.actions.CheckoutNode._callback == 'function')
	{
		org.ametys.repository.actions.CheckoutNode._callback ();
	}
}

//------------------ UNLOCK -----------------------//
org.ametys.repository.actions.UnlockNode = function (node, workspaceName, callback)
{
	org.ametys.repository.actions.UnlockNode._node = node;
	org.ametys.repository.actions.UnlockNode._workspaceName = workspaceName;
	org.ametys.repository.actions.UnlockNode._callback = callback;
	
	org.ametys.repository.actions.UnlockNode.act();
}

org.ametys.repository.actions.UnlockNode.act = function ()
{
	var path = org.ametys.repository.actions.UnlockNode._node.attributes.path.substring(1);
	var workspaceName = org.ametys.repository.actions.UnlockNode._workspaceName;
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, '/repository/unlock-node',
			{
				workspace: workspaceName,
				path: path
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_MAJOR,  
			org.ametys.repository.actions.UnlockNode._callback, 
			this, 
			null);
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
}

org.ametys.repository.actions.UnlockNode._callback = function (response, args)
{
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_UNLOCK_NODE"/>", response, "org.ametys.repository.actions.UnlockNode"))
	{
		return;
	}
	
	if (typeof org.ametys.repository.actions.UnlockNode._callback == 'function')
	{
		org.ametys.repository.actions.UnlockNode._callback ();
	}
}

//------------------ ADD PROPERTY -----------------------//
org.ametys.repository.actions.AddProperty = function (node, workspaceName, callback)
{
	org.ametys.repository.actions.AddProperty._node = node;
	org.ametys.repository.actions.AddProperty._workspaceName = workspaceName;
	org.ametys.repository.actions.AddProperty._callback = callback;
	
	org.ametys.repository.actions.AddProperty.act ();
}

org.ametys.repository.actions.AddProperty.act = function ()
{
	if (!org.ametys.repository.actions.AddProperty.delayedInitialize())
        return;
	
	org.ametys.repository.actions.AddProperty.box.show();
	org.ametys.repository.actions.AddProperty._initForm();
	
	org.ametys.repository.actions.AddProperty._form.getForm().findField('name').focus(true, 100);
}

org.ametys.repository.actions.AddProperty.delayedInitialize = function ()
{
	if (org.ametys.repository.actions.AddProperty._initialized)
		return true;
	
	var combo = new org.ametys.form.ComboField ({
		 fieldLabel: "<i18n:text i18n:key="CREATE_PROP_BOX_TYPE_LABEL"/>",
		 name: 'type',
		 
		 editable: false,
		 triggerAction: 'all',
	     width : 200,
	     
	     mode: 'local',
	     store: ['String','Binary','Long','Double','Date','Boolean','Name','Path','Reference'],
	     
	     emptyText: "<i18n:text i18n:key="CREATE_PROP_BOX_TYPE_COMBO_EMPTY"/>",
	     allowBlank: false,
		 msgTarget: 'side'
	})
	combo.addListener ('select', org.ametys.repository.actions.AddProperty._drawValueField, this);
	
	org.ametys.repository.actions.AddProperty._form = new Ext.FormPanel( {
		labelWidth: 100,
		bodyStyle: 'padding:10px',
		
		defaultType :'textfield',
		
		border: false,
		fileUpload: true,
		autoScroll: true,
		items: [
		        	new org.ametys.HtmlContainer ({cls: 'dialog-text-hint', html: "<i18n:text i18n:key="CREATE_PROP_BOX_HINT"/>" }),
					new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="CREATE_PROP_BOX_NAME_LABEL"/>",
						name: 'name',
					 	width: 200,
						allowBlank: false,
						msgTarget: 'side'
					}),
					combo
		        ]
	});
	
	org.ametys.repository.actions.AddProperty.box = new org.ametys.DialogBox({
		title :"<i18n:text i18n:key="CREATE_PROP_BOX_TITLE"/>",
		icon : context.workspaceContext + "/resources/img/add_properties_16.png",
		
		layout :'fit',
		cls: 'text-dialog',
		width: 420,
		height: 250,
		
		items : [ org.ametys.repository.actions.AddProperty._form ],
		
		closeAction: 'hide',
		buttons : [ {
			text :"<i18n:text i18n:key="DIALOG_BOX_OK"/>",
			handler : org.ametys.repository.actions.AddProperty.ok
		}, {
			text :"<i18n:text i18n:key="DIALOG_BOX_CANCEL"/>",
			handler : org.ametys.repository.actions.AddProperty.cancel
		} ]
	});
	
	
	org.ametys.repository.actions.AddProperty._initialized = true;
	
	return true;
}

org.ametys.repository.actions.AddProperty._drawValueField = function (combo, record, index)
{
	var valueFd = org.ametys.repository.actions.AddProperty._form.getForm().findField('fieldValue');
	if (valueFd != null)
	{
		org.ametys.repository.actions.AddProperty._form.remove(valueFd);
	}
	
	var multipleOldValue = false;
	var multipleFd = org.ametys.repository.actions.AddProperty._form.getForm().findField('multiple');
	if (multipleFd != null)
	{
		multipleOldValue = multipleFd.getValue();
		org.ametys.repository.actions.AddProperty._form.remove(multipleFd);
	}
	
	var hourFd = org.ametys.repository.actions.AddProperty._form.getForm().findField('hour');
	if (hourFd != null)
	{
		org.ametys.repository.actions.AddProperty._form.remove(hourFd);
	}
	
	var drawMultiple = true;
	var type = org.ametys.repository.actions.AddProperty._form.getForm().findField('type').getValue();
	switch (type) 
	{
		case 'Date':
			var valueFd = new org.ametys.form.DateField({
							fieldLabel : "<i18n:text i18n:key="CREATE_PROP_BOX_VALUE_LABEL"/>",
							width: 100,
							name: 'fieldValue',
							format: "<i18n:text i18n:key="DATE_FIELD_FORMAT"/>",
							allowBlank: false,
						    msgTarget: 'side'
			});
			org.ametys.repository.actions.AddProperty._form.add(valueFd);
			
			var hourFd = new org.ametys.form.TimeField({
				fieldLabel: " ",
				labelSeparator: '',
				name: 'hour',
				format: 'H:i:s',
				value: '00:00:00',
				increment: 5,
				width: 100
			});
			org.ametys.repository.actions.AddProperty._form.add(hourFd);
			drawMultiple = false;
			break;
			
		case 'Boolean':
			var valueFd = new org.ametys.form.ComboField({
				fieldLabel: "<i18n:text i18n:key="CREATE_PROP_BOX_VALUE_LABEL"/>",
		    	editable: false,
		    	name: 'fieldValue',
		    	triggerAction: 'all',
		        width : 200,
		    	store: [true, false],
		    	allowBlank: false,
			    msgTarget: 'side'
			});
			drawMultiple = false;
			org.ametys.repository.actions.AddProperty._form.add(valueFd);
			break;
			
		case 'Long':
			var valueFd = new org.ametys.form.LongField({
				fieldLabel : "<i18n:text i18n:key="CREATE_PROP_BOX_VALUE_LABEL"/>",
				name: 'fieldValue',
			    width: 200,
			    allowBlank: false,
			    msgTarget: 'side'
			});
			org.ametys.repository.actions.AddProperty._form.add(valueFd);
			break;
			
		case 'Double':
			var valueFd = new org.ametys.form.DoubleField({
				fieldLabel : "<i18n:text i18n:key="CREATE_PROP_BOX_VALUE_LABEL"/>",
				name: 'fieldValue',
			    width: 200,
			    allowBlank: false,
			    msgTarget: 'side'
			});
			org.ametys.repository.actions.AddProperty._form.add(valueFd);
			break;
			
		case 'Binary':
			var valueFd = new org.ametys.form.FileUploadField({
				fieldLabel : "<i18n:text i18n:key="CREATE_PROP_BOX_VALUE_LABEL"/>",
				name: 'fieldValue',
			    width: 200,
			    allowBlank: false,
			    msgTarget: 'side'
			});
			org.ametys.repository.actions.AddProperty._form.add(valueFd);
			drawMultiple = false;
			break;
			
		default:
			var valueFd = new org.ametys.form.TextField ({
				fieldLabel : "<i18n:text i18n:key="CREATE_PROP_BOX_VALUE_LABEL"/>",
				name: 'fieldValue',
			    width: 200,
			    allowBlank: false,
			    msgTarget: 'side'
			});
			org.ametys.repository.actions.AddProperty._form.add(valueFd);
			break;
	}
	
	if (drawMultiple)
	{
		org.ametys.repository.actions.AddProperty._form.add(new org.ametys.form.BooleanField ({
			fieldLabel : "<i18n:text i18n:key="CREATE_PROP_BOX_MULTIPLE_LABEL"/>",
			desc: "<i18n:text i18n:key="CREATE_PROP_BOX_MULTIPLE_HELP"/>",
			name: 'multiple',
			inputValue: 'true',
			checked: multipleOldValue
		}));
	}
	
	org.ametys.repository.actions.AddProperty._form.doLayout();
}

org.ametys.repository.actions.AddProperty._initForm = function ()
{
	org.ametys.repository.actions.AddProperty._form.getForm().findField('name').setValue('');
	org.ametys.repository.actions.AddProperty._form.getForm().findField('type').setValue('');
	org.ametys.repository.actions.AddProperty._form.getForm().findField('name').clearInvalid();
	var valueFd = org.ametys.repository.actions.AddProperty._form.getForm().findField('fieldValue');
	if (valueFd != null)
	{
		org.ametys.repository.actions.AddProperty._form.remove(valueFd);
	}	
	var multipleFd = org.ametys.repository.actions.AddProperty._form.getForm().findField('multiple');
	if (multipleFd != null)
	{
		org.ametys.repository.actions.AddProperty._form.remove(multipleFd);
	}
	var hourFd = org.ametys.repository.actions.AddProperty._form.getForm().findField('hour');
	if (hourFd != null)
	{
		org.ametys.repository.actions.AddProperty._form.remove(hourFd);
	}
}

org.ametys.repository.actions.AddProperty.ok = function ()
{
	if (!org.ametys.repository.actions.AddProperty._form.getForm().isValid())
	{
		return;
	}
	
	var name = org.ametys.repository.actions.AddProperty._form.getForm().findField('name').getValue();
	var type = org.ametys.repository.actions.AddProperty._form.getForm().findField('type').getValue();
	var field = org.ametys.repository.actions.AddProperty._form.getForm().findField('fieldValue');
	var value = field.fileInput != null ? field.fileInput.getValue() : field.getValue();
	
	var multiple = 'false';
	if (org.ametys.repository.actions.AddProperty._form.getForm().findField('multiple') != null)
	{
		multiple = org.ametys.repository.actions.AddProperty._form.getForm().findField('multiple').getValue().toString();
	}
	
	if (org.ametys.repository.actions.AddProperty._form.getForm().findField('hour') != null)
	{
		var hour = org.ametys.repository.actions.AddProperty._form.getForm().findField('hour').getValue();
		var stringDate = value.format('Y-m-d ') + hour;
		value = Date.parseDate(stringDate, 'Y-m-d H:i:s');
	}
	
	var path = org.ametys.repository.actions.AddProperty._node.attributes.path.substring(1);
	var workspaceName = org.ametys.repository.actions.AddProperty._workspaceName;
	
	org.ametys.repository.actions.AddProperty._form.getForm().submit({
		url : context.workspaceContext + '/repository/set-property',
		params: {
					workspace: workspaceName,
					path: path,
					name: name,
					value: value,
					type: type,
					multiple: multiple
				},
		success: org.ametys.repository.actions.AddProperty._success,
		failure: org.ametys.repository.actions.AddProperty._failure
	});
}

org.ametys.repository.actions.AddProperty._success = function (response, args)
{
	org.ametys.repository.actions.AddProperty._node.select();
	org.ametys.repository.actions.AddProperty.box.hide();
	
	if (typeof org.ametys.repository.actions.AddProperty._callback == 'function')
	{
		org.ametys.repository.actions.AddProperty._callback (org.ametys.repository.actions.AddProperty._node);
	}
}

org.ametys.repository.actions.AddProperty._failure = function (form, action)
{
	new org.ametys.msg.ErrorDialog(
			"<i18n:text i18n:key="CREATE_PROP_ERROR_TITLE"/>", 
			"<i18n:text i18n:key="CREATE_PROP_ERROR_TEXT"/>", 
			action.result.msg,
			null
	);
	return;
}

org.ametys.repository.actions.AddProperty.cancel = function ()
{
	org.ametys.repository.actions.AddProperty.box.hide();
}
//------------------ REMOVE PROPERTY -----------------------//
org.ametys.repository.actions.RemoveProperty = function (node, workspaceName, propertyName, callback)
{
	org.ametys.repository.actions.RemoveProperty._node = node;
	org.ametys.repository.actions.RemoveProperty._workspaceName = workspaceName;
	org.ametys.repository.actions.RemoveProperty._propertyName = propertyName;
	org.ametys.repository.actions.RemoveProperty._callback = callback;
	
	org.ametys.repository.actions.RemoveProperty.act ();
}

org.ametys.repository.actions.RemoveProperty.act = function ()
{
    var path = org.ametys.repository.actions.RemoveProperty._node.attributes.path.substring(1);
	var workspaceName = org.ametys.repository.actions.RemoveProperty._workspaceName;
	
	//remove property from a node in the JCR repository
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, '/repository/remove-property',
			{
				workspace: workspaceName,
				path: path,
				name: org.ametys.repository.actions.RemoveProperty._propertyName
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
			null, 
			this, 
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_REMOVE_PROPERTY"/>", response, "org.ametys.repository.actions.RemoveProperty"))
	{
		return;
	}
	
	if (typeof org.ametys.repository.actions.RemoveProperty._callback == 'function')
	{
		org.ametys.repository.actions.RemoveProperty._callback (org.ametys.repository.actions.RemoveProperty._node, org.ametys.repository.actions.RemoveProperty._propertyName)
	}
}

//------------------ SAVE SESSION -----------------------//

org.ametys.repository.actions.SaveSession = function(workspaceName, callback)
{
    var serverMessage = new org.ametys.servercomm.ServerMessage(
    	'_' + context.workspaceName, 
        '/repository/save-session',
        { workspace: workspaceName }, 
        org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
        null, 
        this, 
        null
    );
    
    var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
    
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='ERROR_MSG_SAVE_SESSION'/>", response, "org.ametys.repository.actions.SaveSession"))
    {
        return;
    }
    
    if (typeof callback == 'function')
    {
        callback();
    }
}

//------------------ ROLLBACK SESSION -----------------------//

org.ametys.repository.actions.RollbackSession = function(workspaceName, callback)
{
    var serverMessage = new org.ametys.servercomm.ServerMessage(
    		'_' + context.workspaceName,
            '/repository/rollback-session',
            { workspace: workspaceName }, 
            org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
            null, 
            this, 
            null
    );
    
    var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
    
    if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key='ERROR_MSG_ROLLBACK_SESSION'/>", response, "org.ametys.repository.actions.RollbackSession"))
    {
        return;
    }
    
    if (callback != null &amp;&amp; typeof callback == 'function')
    {
        callback();
    }
}

//------------------ EXECUTE QUERY -----------------------//
org.ametys.repository.actions.ExecuteQuery = function (tree, workspaceName)
{
	org.ametys.repository.actions.ExecuteQuery._tree = tree;
	org.ametys.repository.actions.ExecuteQuery._workspaceName = workspaceName;
	org.ametys.repository.actions.ExecuteQuery.act ();
}

org.ametys.repository.actions.ExecuteQuery.act = function ()
{
	if (!org.ametys.repository.actions.ExecuteQuery.delayedInitialize())
        return;
	
	org.ametys.repository.actions.ExecuteQuery.box.show();

	org.ametys.repository.actions.ExecuteQuery._form.getForm().findField('query').focus(true, 100);
}

org.ametys.repository.actions.ExecuteQuery.delayedInitialize = function ()
{
	if (org.ametys.repository.actions.ExecuteQuery._initialized)
		return true;
	
	org.ametys.repository.actions.ExecuteQuery._form = new Ext.FormPanel( {
		labelAlign: 'left',
		labelWidth: 60,
		bodyStyle: 'padding:10px',
		
		defaultType :'textfield',
		
		border: false,
		autoScroll: true,
		items: [
					{
					    xtype: 'radiogroup',
					    name: 'language-group',
					    fieldLabel: "<i18n:text i18n:key="XPATH_QUERY_LANGUAGE_LABEL"/>",
					    itemCls: 'ametys-input',
					    labelSeparator: '',
					    width: 200,
					    items: [
					        {boxLabel: 'XPath', name: 'language', inputValue: 'xpath', checked: true},
					        {boxLabel: 'SQL', name: 'language', inputValue: 'sql'}
					    ]
					},
					new org.ametys.form.TextAreaField ({
						fieldLabel : "<i18n:text i18n:key="XPATH_QUERY_PROMPT_LABEL"/>",
						name: 'query',
					 	width: 460, // 520
					 	height: 60,
						allowBlank: false,
						msgTarget: 'side',
						maskRe: /[^\r\n]/,
						stripCharsRe: /[\r\n]/
					}),
					new org.ametys.HtmlContainer ({cls: 'query-text-hint', html: "&lt;u&gt;<i18n:text i18n:key="EXAMPLE_ABBREV"/>&lt;/u&gt;&lt;br/&gt;&lt;span class=\"label\"&gt;XPath:&lt;/span&gt;//element(*, nt:resource)[@jcr:mimeType = 'image/jpeg']&lt;br/&gt;&lt;div class=\"label\"&gt;SQL:&lt;/div&gt;SELECT * FROM nt:resource WHERE jcr:mimeType = 'image/jpeg'"})
		        ]
	});
	
	org.ametys.repository.actions.ExecuteQuery.box = new org.ametys.DialogBox({
		title :"<i18n:text i18n:key="XPATH_QUERY_PROMPT_TITLE"/>",
		icon : context.workspaceContext + "/resources/img/search_16.png",
		
		layout :'fit',
		cls: 'text-dialog',
		width: 600,
		height: 250,
		
		items : [ org.ametys.repository.actions.ExecuteQuery._form
		],
		
		closeAction: 'hide',
		buttons : [ {
			text :"<i18n:text i18n:key="DIALOG_BOX_OK"/>",
			handler : org.ametys.repository.actions.ExecuteQuery.ok
		}, {
			text :"<i18n:text i18n:key="DIALOG_BOX_CANCEL"/>",
			handler : org.ametys.repository.actions.ExecuteQuery.cancel
		} ]
	});
	
	
	org.ametys.repository.actions.ExecuteQuery._initialized = true;
	
	return true;
}

org.ametys.repository.actions.ExecuteQuery.ok = function ()
{
	if (!org.ametys.repository.actions.ExecuteQuery._form.getForm().isValid())
	{
		return;
	}
	
	var workspaceName = org.ametys.repository.actions.ExecuteQuery._workspaceName;
	var xpathQuery = org.ametys.repository.actions.ExecuteQuery._form.getForm().findField('query').getValue();
	var language = org.ametys.repository.actions.ExecuteQuery._form.getForm().findField('language-group').getValue().getGroupValue();
	
	org.ametys.repository.actions.ExecuteQuery.box.hide();
	
	org.ametys.repository.actions.ExecuteQuery._tree.setXPathQuery (xpathQuery, language, workspaceName);
	org.ametys.repository.actions.ExecuteQuery._tree.getRootNode().reload();
}

org.ametys.repository.actions.ExecuteQuery.cancel = function ()
{
	org.ametys.repository.actions.ExecuteQuery.box.hide();
}

//------------------ SOLVE UUID -----------------------//
org.ametys.repository.actions.SolveUUID = function (workspaceName, callback)
{
	org.ametys.repository.actions.SolveUUID._workspaceName = workspaceName;
	org.ametys.repository.actions.SolveUUID._callback = callback;
	
	org.ametys.repository.actions.SolveUUID.act ();
}

org.ametys.repository.actions.SolveUUID.act = function ()
{
	if (!org.ametys.repository.actions.SolveUUID.delayedInitialize())
        return;
	
	org.ametys.repository.actions.SolveUUID.box.show();

	var uuidField = org.ametys.repository.actions.SolveUUID._form.getForm().findField('uuid');
	uuidField.setValue('');
	uuidField.focus(false, 10);
}

org.ametys.repository.actions.SolveUUID.delayedInitialize = function ()
{
	if (org.ametys.repository.actions.SolveUUID._initialized)
		return true;
	
	org.ametys.repository.actions.SolveUUID._form = new Ext.FormPanel( {
		labelAlign: 'top',
		bodyStyle: 'padding:5px',
		defaultType :'textfield',
		
		border: false,
		autoScroll: true,
		items: [
					new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="SOLVE_UUID_PROMPT_TEXT"/>",
						name: 'uuid',
					 	width: 220,
						allowBlank: false,
						msgTarget: 'side'
					})
		        ]
	});
	
	org.ametys.repository.actions.SolveUUID.box = new org.ametys.DialogBox({
		title :"<i18n:text i18n:key="SOLVE_UUID_BUTTON_TOOLTIP_TITLE"/>",
		icon : context.workspaceContext + "/resources/img/search_16.png",
		
		layout :'fit',
		cls: 'text-dialog',
		width: 300,
		height: 150,
		
		items : [ org.ametys.repository.actions.SolveUUID._form
		],
		
		closeAction: 'hide',
		buttons : [ {
			text :"<i18n:text i18n:key="DIALOG_BOX_OK"/>",
			handler : org.ametys.repository.actions.SolveUUID.ok
		}, {
			text :"<i18n:text i18n:key="DIALOG_BOX_CANCEL"/>",
			handler : org.ametys.repository.actions.SolveUUID.cancel
		} ]
	});
	
	
	org.ametys.repository.actions.SolveUUID._initialized = true;
	
	return true;
}

org.ametys.repository.actions.SolveUUID.ok = function ()
{
	if (!org.ametys.repository.actions.SolveUUID._form.getForm().isValid())
	{
		return;
	}
	
	var workspaceName = org.ametys.repository.actions.SolveUUID._workspaceName;
	var uuid = org.ametys.repository.actions.SolveUUID._form.getForm().findField('uuid').getValue();
	
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, '/repository/path-by-uuid',
			{
				workspace: workspaceName,
				uuid: uuid
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
			null, 
			this, 
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_SOLVE_UUID"/>", response, "org.ametys.repository.actions.SolveUUID"))
	{
		return;
	}
	
	// Unknown UUID ?
	if (response.selectSingleNode("unknown") != null)
	{
		Ext.Msg.show({
			title: "<i18n:text i18n:key="SOLVE_UUID_BUTTON_TOOLTIP_TITLE"/>",
			msg: "<i18n:text i18n:key="SOLVE_UUID_UNKNOWN_ITEM_TEXT"/>",
			buttons: Ext.Msg.OK,
			icon: Ext.MessageBox.INFO
		});
		return;
	}
	
	// Repository error ?
	if (response.selectSingleNode("error") != null)
	{
		new org.ametys.msg.ErrorDialog(
				"<i18n:text i18n:key="SOLVE_UUID_BUTTON_TOOLTIP_TITLE"/>", 
				"<i18n:text i18n:key="SOLVE_UUID_ERROR_TEXT"/>", 
				response.selectSingleNode("error")[org.ametys.servercomm.ServerComm.xmlTextContent],
				null
		);
		return;
	}
	
	org.ametys.repository.actions.SolveUUID.box.hide();

	var path = response.selectSingleNode("path")[org.ametys.servercomm.ServerComm.xmlTextContent];
	
	if (typeof org.ametys.repository.actions.SolveUUID._callback == 'function')
	{
		org.ametys.repository.actions.SolveUUID._callback (path);
	}
}

org.ametys.repository.actions.SolveUUID.cancel = function ()
{
	org.ametys.repository.actions.SolveUUID.box.hide();
}


//------------------ CONNECTION -----------------------//
org.ametys.repository.actions.Connect = function ()
{
	org.ametys.repository.actions.Connect.act ();
}

org.ametys.repository.actions.Connect.act = function ()
{
	if (!org.ametys.repository.actions.Connect.delayedInitialize())
	    return;
	
	org.ametys.repository.actions.Connect.box.show();
	
	org.ametys.repository.actions.Connect.init ();
	
	org.ametys.repository.actions.Connect.box.center();
}

org.ametys.repository.actions.Connect.init = function ()
{
	// get parameters from previous use
	var cookie = new Ext.state.CookieProvider();
	var repoPath = cookie.get('repository-path', "");
	var repoXml = cookie.get('repository-xml', "");
	var jcrUser = cookie.get('jackrabbit-user', "");
	var jndiContext = cookie.get('jndi-context', "");
	var jndiUser = cookie.get('jndi-user', "");
	var mode = cookie.get('connection-mode', "");
	
	if (mode == 'jndi')
	{
		Ext.getCmp('jndi-mode').setValue(true);
	}
	else
	{
		Ext.getCmp('jackrabbit-mode').setValue(true);
	}
	
	Ext.getCmp('repository-path').setValue(repoPath);
	Ext.getCmp('repository-xml').setValue(repoXml);
	Ext.getCmp('jackrabbit-user').setValue(jcrUser);
	Ext.getCmp('jndi-context').setValue(jndiContext);
	Ext.getCmp('jndi-user').setValue(jndiUser);
}

org.ametys.repository.actions.Connect.delayedInitialize = function ()
{
	if (org.ametys.repository.actions.Connect._initialized)
		return true;
	
	//Connection Mode
	org.ametys.repository.actions.Connect._form = new Ext.FormPanel( {
		labelAlign: 'right',
		labelWidth: 140,
		bodyStyle: 'padding:5px',
		defaultType :'textfield',
		
		border: false,
		autoScroll: true,
		items: [
		        	new org.ametys.form.RadioGroupField ({
				        fieldLabel: "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_MODE_LABEL"/>",
				        desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_MODE_DESC"/>",
				        width : 300,
				        items: [{
						        	boxLabel: "<i18n:text i18n:key="JACKRABBIT_REPOSITORY_RADIO_LABEL"/>",
						        	id: "jackrabbit-mode",
						            name: 'connection-mode', 
						            value: 'jackrabbit',
						            listeners: {'check':  org.ametys.repository.actions.Connect.selectMode}
					           },
					           {
					        	    boxLabel: "<i18n:text i18n:key="JNDI_RADIO_LABEL"/>",
					        	    id: "jndi-mode",
					        	    name: 'connection-mode', 
					        	    value: 'jndi',
					        	    listeners: {'check':  org.ametys.repository.actions.Connect.selectMode}
					           }
				        ]
				    })
				 ]
	});
		
    //Jackrabbit connection parameters
	org.ametys.repository.actions.Connect._jackrabbitForm = new Ext.form.FieldSet( {
		labelAlign: 'right',
		labelWidth: 130,
		defaultType :'textfield',
		
	    layoutConfig: {
	    	trackLabels: true
		},
		hidden: true,
		border: false,
		autoScroll: true,
		items: [				    
					new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_PATH_LABEL"/>",
						desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_PATH_DESC"/>",
			 	    	name: 'repository-path',
			 	    	id: 'repository-path',
			 	    	width: 300,
						allowBlank: false,
						msgTarget: 'side',
						disabled: true
					}),
				    new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_XML_PATH_LABEL"/>",
						desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_XML_PATH_DESC"/>",
			 	    	name: 'repository-xml',
			 	    	id: 'repository-xml',
			 	    	width: 300,
						allowBlank: false,
						msgTarget: 'side',
						disabled: true
					}),
				    new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_USER_LABEL"/>",
						desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_USER_DESC"/>",
			 	    	name: 'user',
			 	    	id: 'jackrabbit-user',
			 	    	width: 150,
						allowBlank: false,
						msgTarget: 'side',
						disabled: true
					}),
				    new org.ametys.form.PasswordField ({
						fieldLabel : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_PWD_LABEL"/>",
						desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_PWD_DESC"/>",
			 	    	name: 'password',
			 	    	width: 150,
						allowBlank: true,
						msgTarget: 'side',
						disabled: true
					})
				]
	});
	
	org.ametys.repository.actions.Connect._form.add(org.ametys.repository.actions.Connect._jackrabbitForm);

    //JNDI connection parameters
	org.ametys.repository.actions.Connect._jndiForm = new Ext.form.FieldSet ({
		labelAlign: 'right',
		labelWidth: 130,
		bodyStyle: 'padding:5px',
		defaultType :'textfield',
		
	    layoutConfig: {
	    	trackLabels: true
		},
		hidden: true,
		border: false,
		autoScroll: true,
		items: [
					//JNDI
					new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_CONTEXT_LABEL"/>",
						desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_CONTEXT_DESC"/>",
			 	    	name: 'jndi-context',
			 	    	id : 'jndi-context',
			 	    	width: 300,
						allowBlank: false,
						msgTarget: 'side',
						disabled: true
					}),
				    new org.ametys.form.TextField ({
						fieldLabel : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_USER_LABEL"/>",
						desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_USER_DESC"/>",
			 	    	name: 'user',
			 	    	id: 'jndi-user',
			 	    	width: 150,
						allowBlank: false,
						msgTarget: 'side',
						disabled: true
					}),
				    new org.ametys.form.PasswordField ({
						fieldLabel : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_PWD_LABEL"/>",
						desc : "<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_PWD_DESC"/>",
			 	    	name: 'password',
			 	    	width: 150,
						allowBlank: true,
						msgTarget: 'side',
						disabled: true
					})
		        ]
	});
	
	org.ametys.repository.actions.Connect._form.add(org.ametys.repository.actions.Connect._jndiForm);
	
	org.ametys.repository.actions.Connect.box = new org.ametys.DialogBox({
		title :"<i18n:text i18n:key="REPOSITORY_CONNECT_TITLE"/>",
		icon : context.workspaceContext + "/resources/img/disconnect_16.png",
		
		cls: 'text-dialog',
		width: 550,
		height: 250,
		
		items : [ 
		          org.ametys.repository.actions.Connect._form
		],
		
		closable: false,
		defaultButton: 'jackrabbit-mode',
		closeAction: 'hide',
		buttons : [ {
			text :"<i18n:text i18n:key="REPOSITORY_CONNECT_BTN"/>",
			handler : org.ametys.repository.actions.Connect.ok
		} ]
	});
	
	org.ametys.repository.actions.Connect._initialized = true;
	
	return true;
}

org.ametys.repository.actions.Connect.selectMode = function (checkbox, checked)
{
	if (checked &amp;&amp; checkbox.value == 'jackrabbit')
	{
		var form = org.ametys.repository.actions.Connect._jackrabbitForm;
		form.show();
		form.items.each(function(item, index, length){item.enable()});
		
		var form = org.ametys.repository.actions.Connect._jndiForm;
		form.hide();
		form.items.each(function(item, index, length){item.disable()});
	}
	else if (checked &amp;&amp; checkbox.value == 'jndi')
	{
		var form = org.ametys.repository.actions.Connect._jackrabbitForm;
		form.hide();
		form.items.each(function(item, index, length){item.disable()});
		
		var form = org.ametys.repository.actions.Connect._jndiForm;
		form.show();
		form.items.each(function(item, index, length){item.enable()});
	}
}

org.ametys.repository.actions.Connect.ok = function ()
{
	var form = org.ametys.repository.actions.Connect._form.getForm();
	
	var jndiMode = Ext.getCmp ('jndi-mode').checked;
	if (!jndiMode)
	{
		if (!(form.findField ('repository-path').isValid() &amp;&amp; form.findField ('repository-xml').isValid()))
			return;
	}
	else
	{
		if (!form.findField ('jndi-context').isValid())
			return
	}
	
	var params = form.getValues ();
	params.mode = jndiMode ? 'jndi' : 'jackrabbit';
	
	if (org.ametys.repository.ConsoleTab._waitMsg != null)
	{
		org.ametys.repository.ConsoleTab._waitMsg.hide();
	}
	org.ametys.repository.actions.Connect._waitMsg = new org.ametys.msg.Mask(org.ametys.repository.actions.Connect.box.getEl(), "<i18n:text i18n:key="REPOSITORY_CONNECT_WAITING_MSG"/>");
	
	// send message
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, '/repository/register-session',
			params, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
			null, 
			this, 
			null
	);
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
		
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="REPOSITORY_CONNECT_REPOSITORY_ERROR"/>", response, "org.ametys.repository.actions.Connect"))
	{
		org.ametys.repository.actions.Connect._waitMsg.hide();
		delete org.ametys.repository.actions.Connect._waitMsg;
		return;
	}
	
	// save parameters for next use
	var cookie = new Ext.state.CookieProvider();
	cookie.set('repository-path', form.findField ('repository-path').getValue());
	cookie.set('repository-xml', form.findField ('repository-xml').getValue());
	cookie.set('jackrabbit-user', form.findField ('jackrabbit-user').getValue());
	cookie.set('jndi-context', form.findField ('jndi-context').getValue());
	cookie.set('jndi-user', form.findField ('jndi-user').getValue());
	cookie.set('connection-mode', params.mode);
	
	org.ametys.repository.actions.Connect.box.hide();
	
	org.ametys.repository.actions.Connect._waitMsg.hide();
	delete org.ametys.repository.actions.Connect._waitMsg;
		
	// FIXME reload page instead
	var mainPanel = Ext.getCmp('global-tab-panel');
	mainPanel.remove(mainPanel.items.get(0));
	mainPanel.remove(mainPanel.items.get(0));
	mainPanel.remove(mainPanel.items.get(0));
	mainPanel.doLayout();
	
	mainPanel.add([new org.ametys.repository.JCRViewTab(true), new org.ametys.repository.AdminTab(), new org.ametys.repository.ConsoleTab()]);
	
	mainPanel.setActiveTab(0);
}